==> xmonad-0.15-13-x86_64.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.15
id: xmonad-0.15-I2T9Hf6XoUwFTglWz7s3hh
key: xmonad-0.15-I2T9Hf6XoUwFTglWz7s3hh
license: BSD-3-Clause
maintainer: xmonad@haskell.org
author: Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
        Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
        Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
        Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
        Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
        Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
        Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
        Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
        Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
        Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
        Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
        Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
        Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
        Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.
category: System
abi: 5399b06c69c945b20cf406ff33d3d950
exposed: True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
import-dirs: /usr/lib/ghc-8.6.5/site-local/xmonad-0.15
library-dirs: /usr/lib/ghc-8.6.5/site-local/xmonad-0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.15-I2T9Hf6XoUwFTglWz7s3hh
depends:
    X11-1.9-J0U2AuefMGPHH2Zxe9aoxL base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm directory-1.3.3.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    filepath-1.4.2.1 mtl-2.2.2 process-1.6.5.0
    setlocale-1.0.0.8-Eyi756ahEx7HLWAe3k6Ifg unix-2.7.2.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.15-14-x86_64.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.15
id: xmonad-0.15-VK3KvBuqUuGe94FdyBSwD
key: xmonad-0.15-VK3KvBuqUuGe94FdyBSwD
license: BSD-3-Clause
maintainer: xmonad@haskell.org
author: Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
        Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
        Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
        Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
        Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
        Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
        Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
        Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
        Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
        Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
        Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
        Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
        Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
        Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.
category: System
abi: dcc0ae4c97db4b789e78731d1c0514c4
exposed: True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
import-dirs: /usr/lib/ghc-8.6.5/site-local/xmonad-0.15
library-dirs: /usr/lib/ghc-8.6.5/site-local/xmonad-0.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.15-VK3KvBuqUuGe94FdyBSwD
depends:
    X11-1.9-1nMqpZj5GY2I4JDOQviGDl base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-5ccnbkthejE9lCjbHMgc6 directory-1.3.3.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    filepath-1.4.2.1 mtl-2.2.2 process-1.6.5.0
    setlocale-1.0.0.8-Eyi756ahEx7HLWAe3k6Ifg unix-2.7.2.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
